#include "zeusmp.def"
c
c     JCV 2/05/04
c     subroutine to calculate radiative energy loss
c     5/02/04  added physical units and realistic cooling law
c
      subroutine rad_loss
      implicit NONE
#ifdef RAD_LOSS
c
c     standard includes
#include "param.h"
#include "root.h"
#include "field.h"
#include "grid.h"
#include "scratch.h"
#include "gravity.h"
#include "mpicom.h"
#include "cons.h"
#include "mod_names.h"

      integer i,j,k
c  coefficients from cooling formula taken from Ruszkowski & Begelman 2002
      REAL alpha,beta,c1,c2,c3
ccccccccccccccccccccccccccc
c Scaling factors real/code units
      REAL lscale,tiscale,Tescale,mscale,escale
c Scaling for cooling law
      REAL cscale
c Real units mpro[g],kbolt[eV K-1],muu mean moleculare weight
      REAL mpro,kbolt,muu
      REAL delta
      REAL cool
      REAL tkev
      integer tflag ,tflag2
c      REAL olde(in,jn,kn)
      REAL dtcool,coolt
      common / radc / dtcool

cc These values from Ruszkowski & Begelman 2002
      alpha=-1.7
      beta=0.5
      c1=8.6E-3
      c2=5.8E-2
      c3=6.4E-2
cccccccccccccccccccccc

      muu=1.27
      mpro=1.6726231E-24
      kbolt=1.4861E-9

      lscale=rcore*1000*3.086E18/2
      tiscale=lscale/(cism*1000*100)
      Tescale=mpro*muu*((cism*1000*100)**2)
     &     /(gamma*kbolt*3.0/5.0)
      mscale=muu*mpro*ncent*(lscale**3)
      escale=(lscale**2)*mscale/(tiscale**2)
      cscale=(escale*(lscale**3))/(tiscale)

c      if(time .eq. 0.0)then
c         write(*,*)"lscale= ",lscale
c         write(*,*)"tiscale= ",tiscale
c         write(*,*)"Tescale= ", Tescale
c         write(*,*)"mscale= ",mscale
c         write(*,*)"escale= ",escale
c         write(*,*)"cscale= ",cscale
c      endif

c set dtrcool2 equal to something large
      dtcool=1000.0

      delta=0
      cool=0
      tflag=0
      tflag2=0

      do k=ks,ke
         do j=js,je
            do i=is,ie
               tkev=Tescale*(gamma-1)*e(i,j,k)/d(i,j,k)
               if (tkev .GE. tmin) then
c calculate loss
                  delta=((c1*(tkev**alpha))+(c2*(tkev**beta))+c3)*10E-22
                  cool=(delta/cscale)*0.704*
     &            ((mscale*d(i,j,k)/mpro)**2)
c update energy
c                  olde(i,j,k)=e(i,j,k)
                  e(i,j,k)=e(i,j,k)-(dt*cool)
c                  e(i,j,k)=e(i,j,k)-0.01*e(i,j,k)*dt*d(i,j,k)**2
c  newdt
                  coolt=0.1*(e(i,j,k)/(cool*dt))
                  if (dtcool .GT. coolt) then
                     dtcool = coolt
                     tflag=1
                  endif
               else
                  tflag=1
               endif
      
               if(e(i,j,k).le.0.0)then
                  write(*,*)'Negative energy in cooling 
     &                 at',i,j,k,myid
                  call hdfall('last_output.hdf')
                  call MPI_FINALIZE
                  stop
               endif

            enddo
         enddo
      enddo
      if (tflag.GT.0)then
         write(2,*)'Temperature below ',tmin,'at t= ',time
      endif
      if(tflag2.gt.0)then
c         if(myid.eq.0)then
            write(*,*)"Using cooling time step"
c         endif
      endif



#endif /* RAD_LOSS */
      return
      end
